@@ -143,11 +143,11 @@ def main():
         LOG.info("Vulnerability database loaded from {}".format(config.vdb_bin_file))
 
     if args.cache:
-        for s in [NvdSource(), GitHubSource()]:
+        for s in [GitHubSource(), NvdSource()]:
             LOG.info("Refreshing {}".format(s.__class__.__name__))
             s.refresh()
     elif args.sync:
-        for s in [NvdSource(), GitHubSource()]:
+        for s in [GitHubSource(), NvdSource()]:
             LOG.info("Syncing {}".format(s.__class__.__name__))
             s.download_recent()
     if args.sync_npm:
